@@ -1,13 +1,11 @@
-#!/usr/bin/env python
-from .saucenao_api import SauceNao
 from .containers import BasicSauce, BookSauce, VideoSauce
-
+from .saucenao_api import SauceNao
 
 __author__ = 'nomnoms12'
-__copyright__ = 'Copyright (c) 2020 nomnoms12'
-__credits__ = ['nomnoms12']
-__license__ = 'MIT'
-__version__ = '1.0.0'
+__copyright__ = 'Copyright 2020, Taiga.sh Development'
+__credits__ = ['nomnoms12', 'FujiMakoto']
+__license__ = 'GNU General Public License v3.0'
+__version__ = '2.0.1'
 __maintainer__ = 'nomnoms12'
 __email__ = 'alexander.ign0918@gmail.com'
 __status__ = 'Production'
