@@ -1,21 +1,20 @@
-#!/usr/bin/env python
 from typing import Optional, List
+
 from .params import DB
 
 
 class BasicSauce:
     def __init__(self, raw):
         result_header = raw['header']
-        data = raw['data']
 
         self.raw:        dict = raw
         self.similarity: float = float(result_header['similarity'])
         self.thumbnail:  str = result_header['thumbnail']
         self.index_id:   int = result_header['index_id']
         self.index_name: str = result_header['index_name']
-        self.title:      Optional[str] = self._get_title(data)
-        self.url:        Optional[str] = self._get_url(data)
-        self.author:     Optional[str] = self._get_author(data)
+        self.title:      Optional[str] = self._get_title(raw['data'])
+        self.url:        Optional[str] = self._get_url(raw['data'])
+        self.author:     Optional[str] = self._get_author(raw['data'])
 
     @staticmethod
     def _get_title(data):
@@ -57,6 +56,12 @@ class BasicSauce:
                 return data['creator'][0]
             return data['creator']
 
+    def __str__(self):
+        return self.title
+
+    def __repr__(self):
+        return f'<BasicSauce(title={repr(self.title)}, similarity={self.similarity:.2f})>'
+
 
 class BookSauce(BasicSauce):
     def __init__(self, result):
@@ -65,6 +70,9 @@ class BookSauce(BasicSauce):
 
         self.part: str = data['part']
 
+    def __repr__(self):
+        return f'<BookSauce(title={repr(self.title)}, part={repr(self.part)}, similarity={self.similarity:.2f})>'
+
 
 class VideoSauce(BasicSauce):
     def __init__(self, result):
@@ -75,6 +83,9 @@ class VideoSauce(BasicSauce):
         self.year:     str = data['year']
         self.est_time: str = data['est_time']
 
+    def __repr__(self):
+        return f'<VideoSauce(title={repr(self.title)}, part={repr(self.part)}, similarity={self.similarity:.2f})>'
+
 
 class SauceResponse:
     _BOOK_INDEXES = [DB.HMagazines, DB.Madokami, DB.MangaDex]
@@ -85,18 +96,16 @@ class SauceResponse:
         parsed_results = self._parse_results(resp['results'])
 
         self.raw:                 dict = resp
-        self.user_id:             str = resp_header['user_id']
-        self.account_type:        str = resp_header['account_type']
+        self.user_id:             int = resp_header['user_id']
+        self.account_type:        int = resp_header['account_type']
         self.short_limit:         str = resp_header['short_limit']
         self.long_limit:          str = resp_header['long_limit']
         self.long_remaining:      int = resp_header['long_remaining']
         self.short_remaining:     int = resp_header['short_remaining']
         self.status:              int = resp_header['status']
-        self.results_requested:   str = resp_header['results_requested']
+        self.results_requested:   int = resp_header['results_requested']
         self.search_depth:        str = resp_header['search_depth']
         self.minimum_similarity:  float = resp_header['minimum_similarity']
-        self.query_image_display: str = resp_header['query_image_display']
-        self.query_image:         str = resp_header['query_image']
         self.results_returned:    int = resp_header['results_returned']
         self.results:             List[BasicSauce] = parsed_results
 
@@ -104,10 +113,10 @@ class SauceResponse:
         if results is None:
             return []
 
-        filtered_results = sorted(results, key=lambda r: float(r['header']['similarity']), reverse=True)
+        sorted_results = sorted(results, key=lambda r: float(r['header']['similarity']), reverse=True)
 
         parsed_results = []
-        for result in filtered_results:
+        for result in sorted_results:
             index_id = result['header']['index_id']
             if index_id in self._BOOK_INDEXES:
                 parsed_results.append(BookSauce(result))
@@ -120,9 +129,12 @@ class SauceResponse:
     def __len__(self):
         return len(self.results)
 
+    def __bool__(self):
+        return bool(self.results)
+
     def __getitem__(self, item):
         return self.results[item]
 
     def __repr__(self):
-        return (f'<SauceResponse(results_count={len(self.results)}, long_remaining={self.long_remaining}, '
-                f'short_remaining={self.short_remaining})>')
+        return (f'<SauceResponse(count={repr(len(self.results))}, long_remaining={repr(self.long_remaining)}, '
+                f'short_remaining={repr(self.short_remaining)})>')
